@@ -97,6 +97,8 @@ VirtualDisk = collections.namedtuple(
 
 NO_FOREIGN_DRIVES = ["STOR058", "STOR018"]
 
+_STARTING_LBA_AUTO_CALCULATE = '0xFFFFFFFFFFFFFFFF'
+
 
 class RAIDAttribute(object):
     """Generic RAID attribute class"""
@@ -672,6 +674,15 @@ class RAIDManagement(object):
             virtual_disk_prop_names.append('SpanLength')
             virtual_disk_prop_values.append(str(span_length))
 
+        # Necessary when creating more than 1 VD on  same physical disks.
+        # To keep things simple, passing this all the time as no harm to pass
+        # this when creating only 1 VD taking all physical disk space.
+        # Passed value '0xFFFFFFFFFFFFFFFF' instructs iDRAC to calculate the
+        # value programmatically on its side. For single or first VD that would
+        # be 0.
+        virtual_disk_prop_names.append('StartingLBA')
+        virtual_disk_prop_values.append(_STARTING_LBA_AUTO_CALCULATE)
+
         if error_msgs:
             msg = ('The following errors were encountered while parsing '
                    'the provided parameters: %r') % ','.join(error_msgs)
@@ -911,6 +922,15 @@ class RAIDManagement(object):
         RAID to JBOD or vice versa.  It does this by only converting the
         disks that are not already in the correct state.
 
+        When converting Dell EMC PERC H755 RAID controller physical disks
+        to non-RAID mode, RAID-0 virtual disks get created for each physical
+        disk and disks moved to 'Online' state.
+
+        This is different from other controllers supporting non-RAID conversion
+        and takes up physical disks that cannot be later used for user intended
+        RAID configuration. H755 RAID controllers are excluded when converting
+        to non-RAID mode leaving disks in 'Ready' state.
+
         :param mode: constants.RaidStatus enumeration that indicates the mode
                      to change the disks to.
         :param controllers_to_physical_disk_ids: Dictionary of controllers and
@@ -932,11 +952,12 @@ class RAIDManagement(object):
         physical_disks = self.list_physical_disks()
 
         raid = constants.RaidStatus.raid
+        jbod = constants.RaidStatus.jbod
 
+        all_controllers = self.list_raid_controllers()
         if not controllers_to_physical_disk_ids:
             controllers_to_physical_disk_ids = collections.defaultdict(list)
 
-            all_controllers = self.list_raid_controllers()
             for physical_d in physical_disks:
                 # Weed out disks that are not attached to a RAID controller
                 if self.is_raid_controller(physical_d.controller,
@@ -946,6 +967,27 @@ class RAIDManagement(object):
 
                     physical_disk_ids.append(physical_d.id)
 
+        controllers_to_results = {}
+
+        # Filter out PERC H755 controller as it creates RAID-0 virtual disks
+        # when in non-RAID mode. Returns conversion result dictionary
+        # containing is_commit_required and is_reboot_required key with
+        # the value always set to False.
+        if mode == jbod:
+            for cntlr in all_controllers:
+                if cntlr.model.startswith("PERC H755") and \
+                 cntlr.id in controllers_to_physical_disk_ids:
+                    LOG.debug("Excluding {} from converting to "
+                              "non-RAID mode".format(cntlr.model))
+                    del controllers_to_physical_disk_ids[cntlr.id]
+                    controllers_to_results[cntlr.id] = \
+                        utils.build_return_dict(
+                            doc=None,
+                            resource_uri=None,
+                            is_commit_required_value=False,
+                            is_reboot_required_value=constants.
+                            RebootRequired.false)
+
         '''Modify controllers_to_physical_disk_ids dict by inspecting desired
         status vs current status of each controller's disks.
         Raise exception if there are any failed drives or
@@ -954,7 +996,6 @@ class RAIDManagement(object):
         final_ctls_to_phys_disk_ids = self._check_disks_status(
                 mode, physical_disks, controllers_to_physical_disk_ids)
 
-        controllers_to_results = {}
         for controller, physical_disk_ids \
                 in final_ctls_to_phys_disk_ids.items():
             if physical_disk_ids:
