@@ -184,6 +184,47 @@ class ClientiDRACCardConfigurationTestCase(base.BaseTest):
         self.assertEqual(expected_enum_attr, idrac_settings[
                          'Info.1#Type'])
 
+    def test_list_idrac_settings_with_nil_group_id(
+             self, mock_requests, mock_wait_until_idrac_is_ready):
+
+        mock_requests.post('https://1.2.3.4:443/wsman', [
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardEnumeration]['ok']},
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardString]['nil_group_id']},
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardInteger]['ok']}])
+        self.drac_client.list_idrac_settings(
+             by_name=True, fqdd_filter='iDRAC.Embedded.1')
+
+    def test_list_idrac_settings_with_nil_lower_bound(
+             self, mock_requests, mock_wait_until_idrac_is_ready):
+
+        mock_requests.post('https://1.2.3.4:443/wsman', [
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardEnumeration]['ok']},
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardString]['ok']},
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardInteger]['nil_lower_bound']}])
+
+        self.drac_client.list_idrac_settings(
+             by_name=True, fqdd_filter='iDRAC.Embedded.1')
+
+    def test_list_idrac_settings_with_nil_upper_bound(
+             self, mock_requests, mock_wait_until_idrac_is_ready):
+
+        mock_requests.post('https://1.2.3.4:443/wsman', [
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardEnumeration]['ok']},
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardString]['ok']},
+             {'text': test_utils.iDracCardEnumerations[
+                 uris.DCIM_iDRACCardInteger]['nil_upper_bound']}])
+
+        self.drac_client.list_idrac_settings(
+             by_name=True, fqdd_filter='iDRAC.Embedded.1')
+
     @mock.patch.object(dracclient.client.WSManClient, 'invoke',
                        spec_set=True, autospec=True)
     def test_set_idrac_settings(
