@@ -163,10 +163,16 @@ iDracCardEnumerations = {
         'ok': load_wsman_xml('idraccard_enumeration-enum-ok')
     },
     uris.DCIM_iDRACCardString: {
-        'ok': load_wsman_xml('idraccard_string-enum-ok')
+        'ok': load_wsman_xml('idraccard_string-enum-ok'),
+        'nil_group_id': load_wsman_xml(
+                        'idraccard_string-enum-nil-group-id')
     },
     uris.DCIM_iDRACCardInteger: {
-        'ok': load_wsman_xml('idraccard_integer-enum-ok')
+        'ok': load_wsman_xml('idraccard_integer-enum-ok'),
+        'nil_lower_bound': load_wsman_xml(
+                           'idraccard_integer-enum-nil-lower-bound'),
+        'nil_upper_bound': load_wsman_xml(
+                           'idraccard_integer-enum-nil-upper-bound')
     },
 }
 
